import * as asyncHandler from 'express-async-handler';
import * as userBiz from '../biz/fuHuqQi/user';
import * as baseBiz from '../biz/fuHuqQi/base';
import * as enterpriseBiz from '../biz/enterprise/enterprise';
import * as financingBiz from '../biz/enterprise/financing';
import { checkReqParam } from '../util/tools';
import { BizError } from '../util/bizError';
import { ERRORENUM } from '../config/errorEnum';


export function setRouter(httpServer) {
    // /**登录 */
    // httpServer.post('/admin/login', asyncHandler(login));
    // /** 孵化器*/
    httpServer.post('/admin/fuhuaqi/baselist', asyncHandler(fuHuaQiBaseList));
    // httpServer.post('/admin/fuhuaqi/monthoccupancyrate', asyncHandler());
    httpServer.post('/admin/fuhuaqi/userlist', asyncHandler(getFuHuaQiUserList));
    httpServer.post('/admin/fuhuaqi/updatestate', asyncHandler(updateState));
    /**企业 */
    httpServer.post('/admin/enterprise/list', asyncHandler(getEnterpriseList));
    httpServer.post('/admin/enterprise/financinglist', asyncHandler(getFinancingList));
    
}
    

/**
 * 管理后天登录
 * @param req 
 * @param res 
 */
async function login(req, res) {
    let reqConf = {loginId:'String', pwd:'String'};
    let {uscc, pwd} = checkReqParam(reqConf, req.body);

    let userInfo = await userBiz.login(uscc, pwd);
    res.success(userInfo);
}


/**
 * 孵化器基本信息列表
 * @param req 
 * @param res 
 */
async function fuHuaQiBaseList(req, res) {
    let {lv, institutionalNature, industry, page} = req.body;
    if (typeof lv != 'number' || typeof institutionalNature != 'number' || typeof industry != 'number') {
        throw new BizError(ERRORENUM.参数错误, lv, institutionalNature, industry);
    }
    if (!page || typeof page !="number") throw new BizError(ERRORENUM.参数错误, `page:${page}`); 
    
    let result = await baseBiz.fuHuaQiBaseList(lv, institutionalNature, industry, page);

    res.success(result);
}


/**
 * 后台管理 获取孵化器账号信息列表 
 * @param req 
 * @param res 
 */
 async function getFuHuaQiUserList(req, res) {
    let reqConf = {operationName: 'string', page: 'number' };
    let { operationName, page } = checkReqParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await userBiz.fuHuaQiUserList(operationName, page);
    res.success(result);
}


/**
 * 后台管理 获取融资企业信息列表 
 * @param req 
 * @param res 
 */
 async function getFinancingList(req, res) {
    let reqConf = {month: 'string', belongToIncubator: 'string', industry: 'string', fuHuaQiInvestment: 'boolean', page: 'number' };
    let { month, belongToIncubator, industry, fuHuaQiInvestment, page } = checkReqParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await financingBiz.financingList(month, belongToIncubator, industry, fuHuaQiInvestment, page);
    res.success(result);
}


/**
 * 后台管理 获取在孵企业信息列表 
 * @param req 
 * @param res 
 */
 async function getEnterpriseList(req, res) {
    let reqConf = {logonTime: 'number', timeOfImmigration: 'number', fuHuaQiUscc: 'string', industry: 'number', isNaturalPersonHolding: 'boolean', page: 'number' };
    let { time, fuHuaQiUscc, industry, isNaturalPersonHolding, page } = checkReqParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await enterpriseBiz.enterpriseList(time, fuHuaQiUscc, industry, isNaturalPersonHolding, page);
    res.success(result);
}


/**
 * 后台管理 修改孵化器账号状态 
 * @param req 
 * @param res 
 */
 async function updateState(req, res) {
    let reqConf = {userState: 'number', uscc: 'string' };
    let { userState, uscc } = checkReqParam(reqConf, req.body);
    const Uscc = req.headers.uscc;

    let result = await userBiz.updateState(userState, uscc);
    res.success(result);
}


